Coverage for scipy\__config__.py: 0%

# Coverage for scipy\__config__.py : 0%

## 25 statements 0 run 25 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 | # This file is generated by numpy's setup.py # It contains system_info results at the time of building this package. __all__ = ["get_info","show"] import os import sys extra_dll_dir = os.path.join(os.path.dirname(__file__), '.libs') if sys.platform == 'win32' and os.path.isdir(extra_dll_dir): os.environ.setdefault('PATH', '') os.environ['PATH'] += os.pathsep + extra_dll_dir lapack_mkl_info={'libraries': ['mkl_blas95', 'mkl_lapack95', 'mkl_rt'], 'library_dirs': ['C:/Program Files (x86)/IntelSWTools/compilers_and_libraries_2019/windows/mkl/lib/ia32_win'], 'define_macros': [('SCIPY_MKL_H', None), ('HAVE_CBLAS', None)], 'include_dirs': ['C:\\Program Files (x86)\\IntelSWTools\\compilers_and_libraries_2019\\windows\\mkl', 'C:\\Program Files (x86)\\IntelSWTools\\compilers_and_libraries_2019\\windows\\mkl\\include', 'C:\\Program Files (x86)\\IntelSWTools\\compilers_and_libraries_2019\\windows\\mkl\\lib', 'C:/Program Files (x86)/IntelSWTools/compilers_and_libraries_2019/windows/mkl/include']} lapack_opt_info={'libraries': ['mkl_blas95', 'mkl_lapack95', 'mkl_rt'], 'library_dirs': ['C:/Program Files (x86)/IntelSWTools/compilers_and_libraries_2019/windows/mkl/lib/ia32_win'], 'define_macros': [('SCIPY_MKL_H', None), ('HAVE_CBLAS', None)], 'include_dirs': ['C:\\Program Files (x86)\\IntelSWTools\\compilers_and_libraries_2019\\windows\\mkl', 'C:\\Program Files (x86)\\IntelSWTools\\compilers_and_libraries_2019\\windows\\mkl\\include', 'C:\\Program Files (x86)\\IntelSWTools\\compilers_and_libraries_2019\\windows\\mkl\\lib', 'C:/Program Files (x86)/IntelSWTools/compilers_and_libraries_2019/windows/mkl/include']} blas_mkl_info={'libraries': ['mkl_blas95', 'mkl_lapack95', 'mkl_rt'], 'library_dirs': ['C:/Program Files (x86)/IntelSWTools/compilers_and_libraries_2019/windows/mkl/lib/ia32_win'], 'define_macros': [('SCIPY_MKL_H', None), ('HAVE_CBLAS', None)], 'include_dirs': ['C:\\Program Files (x86)\\IntelSWTools\\compilers_and_libraries_2019\\windows\\mkl', 'C:\\Program Files (x86)\\IntelSWTools\\compilers_and_libraries_2019\\windows\\mkl\\include', 'C:\\Program Files (x86)\\IntelSWTools\\compilers_and_libraries_2019\\windows\\mkl\\lib', 'C:/Program Files (x86)/IntelSWTools/compilers_and_libraries_2019/windows/mkl/include']} blas_opt_info={'libraries': ['mkl_blas95', 'mkl_lapack95', 'mkl_rt'], 'library_dirs': ['C:/Program Files (x86)/IntelSWTools/compilers_and_libraries_2019/windows/mkl/lib/ia32_win'], 'define_macros': [('SCIPY_MKL_H', None), ('HAVE_CBLAS', None)], 'include_dirs': ['C:\\Program Files (x86)\\IntelSWTools\\compilers_and_libraries_2019\\windows\\mkl', 'C:\\Program Files (x86)\\IntelSWTools\\compilers_and_libraries_2019\\windows\\mkl\\include', 'C:\\Program Files (x86)\\IntelSWTools\\compilers_and_libraries_2019\\windows\\mkl\\lib', 'C:/Program Files (x86)/IntelSWTools/compilers_and_libraries_2019/windows/mkl/include']} def get_info(name): g = globals() return g.get(name, g.get(name + "_info", {})) def show(): for name,info_dict in globals().items(): if name[0] == "_" or type(info_dict) is not type({}): continue print(name + ":") if not info_dict: print(" NOT AVAILABLE") for k,v in info_dict.items(): v = str(v) if k == "sources" and len(v) > 200: v = v[:60] + " ...\n... " + v[-60:] print(" %s = %s" % (k,v))